@@ -395,7 +395,7 @@ static void Ax_plus_y_test(Coord a, point x, point y) {
 // ----------------------------------------------------------------
 static void Vec_scale_test(int n, Coord a, Coord *x)
 {
-  register Coord *xx = x,
+  Coord *xx = x,
     *xend = xx + n   ;
   while (xx!=xend) {
     *xx *= a;
